@@ -11,10 +11,11 @@
 #' @param url character URL to ping to check for a working connection
 #' @return If offline, a test skip; else invisibly returns TRUE.
 #' @seealso [testthat::skip()]
-#' @importFrom testthat skip
+#' @importFrom testthat skip skip_on_cran
 #' @export
 skip_if_disconnected <- function (message=paste("Offline: cannot reach", url),
                                   url="http://httpbin.org/") {
+    skip_on_cran()
     if (currently_offline(url)) {
         skip(message)
     }
