@@ -2,10 +2,10 @@
 #'
 #' `without_internet` simulates the situation when any network request will
 #' fail, as in when you are without an internet connection. Any HTTP request
-#' through the verb functions in `httr`, or [utils::download.file()], will raise
+#' through the verb functions in `httr` will raise
 #' an error. The error message raised has a well-defined shape, made of three
 #' elements, separated by space: (1) the request
-#' method (e.g. "GET", or for downloading, "DOWNLOAD"); (2) the request URL; and
+#' method (e.g. "GET"); (2) the request URL; and
 #' (3) the request body, if present. The verb-expectation functions,
 #' such as [expect_GET()] and [expect_POST()], look for this shape.
 #' @param expr Code to run inside the mock context
@@ -23,7 +23,6 @@
 without_internet <- function (expr) {
     with_mock(
         `httr:::request_perform`=stopRequest,
-        `utils::download.file`=stopDownload,
         eval.parent(expr)
     )
 }
@@ -41,7 +40,3 @@ stopRequest <- function (req, handle, refresh) {
     }
     stop(out, call.=FALSE)
 }
-
-stopDownload <- function (url, ...) {
-    stop("DOWNLOAD ", url, call.=FALSE)
-}
